@@ -15,6 +15,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+set -e 
+
 usage() {
     echo "usage: $PROG [-C file] [-F file] args"
     echo "       -C file                                   - Use alternate file for config.yaml"
@@ -22,6 +24,7 @@ usage() {
     echo "  commands:"
     echo "       -c NUM_INSTANCES, --create NUM_INSTANCES  - Create a Docker based Bigtop Hadoop cluster"
     echo "       -d, --destroy                             - Destroy the cluster"
+    echo "       -dcp, --docker-compose-plugin             - Execute docker compose plugin command 'docker compose'"
     echo "       -e, --exec INSTANCE_NO|INSTANCE_NAME      - Execute command on a specific instance. Instance can be specified by name or number"
     echo "                                                   For example: $PROG --exec 1 bash"
     echo "                                                                $PROG --exec docker_bigtop_1 bash"
@@ -53,7 +56,7 @@ create() {
         log "Cluster already exist! Run ./$PROG -d to destroy the cluster or delete .provision_id file and containers manually."
         exit 1;
     fi
-    echo "`date +'%Y%m%d_%H%M%S'`_R$RANDOM" > .provision_id
+    echo "`date +'%Y%m%d_%H%M%S'`_r$RANDOM" > .provision_id
     PROVISION_ID=`cat .provision_id`
     # Create a shared /etc/hosts and hiera.yaml that will be both mounted to each container soon
     mkdir -p config/hieradata 2> /dev/null
@@ -128,7 +131,7 @@ create() {
 generate-hosts() {
     get_nodes
     for node in ${NODES[*]}; do
-        entry=`docker inspect --format "{{.NetworkSettings.IPAddress}} {{.Config.Hostname}}.{{.Config.Domainname}} {{.Config.Hostname}}" $node`
+        entry=`docker inspect --format "{{range.NetworkSettings.Networks}}{{.IPAddress}}{{end}} {{.Config.Hostname}}.{{.Config.Domainname}} {{.Config.Hostname}}" $node`
         docker exec ${NODES[0]} bash -c "echo $entry >> /etc/hosts"
     done
     wait
@@ -141,27 +144,13 @@ generate-config() {
     # add ip of all nodes to config
     get_nodes
     for node in ${NODES[*]}; do
-        this_node_ip=`docker inspect --format "{{.NetworkSettings.IPAddress}}" $node`
+        this_node_ip=`docker inspect -f "{{range.NetworkSettings.Networks}}{{.IPAddress}}{{end}}" $node`
         node_list="$node_list$this_node_ip "
     done
     node_list=$(echo "$node_list" | xargs | sed 's/ /, /g')
     cat $BIGTOP_PUPPET_DIR/hiera.yaml >> ./config/hiera.yaml
     cp -vfr $BIGTOP_PUPPET_DIR/hieradata ./config/
 
-    # A workaround for starting Elasticsearch on ppc64le.
-    # See BIGTOP-3574 for details.
-    running_arch=$(uname -m)
-    if [ "ppc64le" == ${running_arch} ]; then
-        elasticsearch_bootstrap_system_call_filter=false
-    else
-        elasticsearch_bootstrap_system_call_filter=true
-    fi
-
-    # Using FairScheduler instead of CapacityScheduler here is a workaround for BIGTOP-3406.
-    # Due to the default setting of the yarn.scheduler.capacity.maximum-am-resource-percent
-    # property defined in capacity-scheduler.xml (=0.1), some oozie jobs are not assigned
-    # enough resource to succeed. But this property can't be set via hiera for now,
-    # so we use FairScheduler as an easy workaround.
     cat > ./config/hieradata/site.yaml << EOF
 bigtop::hadoop_head_node: $1
 hadoop::hadoop_storage_dirs: [/data/1, /data/2]
@@ -169,8 +158,7 @@ bigtop::bigtop_repo_uri: $2
 bigtop::bigtop_repo_gpg_check: $gpg_check
 hadoop_cluster_node::cluster_components: $3
 hadoop_cluster_node::cluster_nodes: [$node_list]
-hadoop::common_yarn::yarn_resourcemanager_scheduler_class: org.apache.hadoop.yarn.server.resourcemanager.scheduler.fair.FairScheduler
-elasticsearch::bootstrap::system_call_filter: $elasticsearch_bootstrap_system_call_filter
+hadoop::common_yarn::yarn_resourcemanager_scheduler_class: org.apache.hadoop.yarn.server.resourcemanager.scheduler.capacity.CapacityScheduler
 EOF
 }
 
@@ -208,7 +196,9 @@ provision() {
         ) &
     done
     wait
-    cat .error_msg_* 2>/dev/null && exit 1
+    if [ `find . -maxdepth 1 -type f -name ".error_msg_*" | wc -l` -gt 0 ]; then
+      cat .error_msg_* 2>/dev/null && exit 1
+    fi
 }
 
 smoke-tests() {
@@ -226,10 +216,17 @@ destroy() {
     else
         get_nodes
         docker exec ${NODES[0]} bash -c "umount /etc/hosts; rm -f /etc/hosts"
+        NETWORK_ID=`docker network ls --quiet --filter name=${PROVISION_ID}_default`
+
         if [ -n "$PROVISION_ID" ]; then
             $DOCKER_COMPOSE_CMD -p $PROVISION_ID stop
             $DOCKER_COMPOSE_CMD -p $PROVISION_ID rm -f
+            
         fi
+
+        if [ -n "$NETWORK_ID" ]; then
+            docker network rm ${PROVISION_ID}_default
+        fi 
         rm -rvf ./config .provision_id .error_msg*
     fi
 }
@@ -307,6 +304,10 @@ get_nodes() {
     fi
 }
 
+change_docker_compose_cmd() {
+    DOCKER_COMPOSE_CMD="docker compose"
+}
+
 PROG=`basename $0`
 
 if [ $# -eq 0 ]; then
@@ -316,6 +317,13 @@ fi
 yamlconf="config.yaml"
 DOCKER_COMPOSE_CMD="docker-compose"
 
+for arg in $@
+do
+   if [ "$arg" == "-dcp" ] || [ "$arg" == "--docker-compose-plugin" ]; then 
+       change_docker_compose_cmd
+   fi
+done
+
 BIGTOP_PUPPET_DIR=../../bigtop-deploy/puppet
 if [ -e .provision_id ]; then
     PROVISION_ID=`cat .provision_id`
@@ -349,6 +357,8 @@ while [ $# -gt 0 ]; do
     -d|--destroy)
         destroy
         shift;;
+    -dcp|--docker-compose-plugin)
+        shift;;
     -e|--exec)
         if [ $# -lt 3 ]; then
           echo "exec command takes 2 parameters: 1) instance no 2) command to be executed" 1>&2
@@ -405,7 +415,7 @@ while [ $# -gt 0 ]; do
         shift 2;;
     -n|--nexus)
         if [ $# -lt 2 ] || [[ $2 == -* ]]; then
-            NEXUS_IP=`docker inspect --format "{{.NetworkSettings.IPAddress}}" nexus`
+            NEXUS_IP=`docker inspect --format "{{range.NetworkSettings.Networks}}{{.IPAddress}}{{end}}" nexus`
             if [ $? != 0 ]; then
                 log "No container named nexus exists. To create one:\n $ docker run -d --name nexus sonatype/nexus"
                 exit 1
